Configuration file parsing (TOML format).
Reads trip-test.toml for settings like baseline snapshot path and server command.
Structs
- Diff
Config - Server
Config - Snapshot
Config - Snapshot configuration section.
- Trip
Test Config
Configuration file parsing (TOML format).
Reads trip-test.toml for settings like baseline snapshot path and server command.