pub struct MCPClient { /* private fields */ }Expand description
MCP client for communicating with servers over stdio transport.
Implementations
Sourceimpl MCPClient
impl MCPClient
Sourcepub async fn new(server_cmd: &str) -> Result<Self>
pub async fn new(server_cmd: &str) -> Result<Self>
Create a new MCP client and connect to a server via stdio.
Arguments
server_cmd- Command to spawn the server (e.g., “python -m my_server”)
pub async fn call_tool(&mut self, tool_name: &str, args: Value) -> Result<Value>
pub async fn list_tools(&mut self) -> Result<Vec<Tool>>
pub fn get_server_name(&self) -> String
pub fn get_server_version(&self) -> String